# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# this file is part of mkp package "veeamcc_tenant"
# see package description for details and maintainer
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# tails. You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
#

#
# Load Veeam Backup and Replication Powershell Snapin
#
Add-PSSnapin VeeamPSSnapIn -ErrorAction SilentlyContinue

#
# get cloud repos
#
$cloudrepos = (Get-VBRBackupRepository |  where { $_.type -match 'Cloud'})

if ($cloudrepos)
{

  #
  # identify service to checkmk
  #
  echo "<<<veeamcc_tenant_cloudrepo>>>"
  foreach ($cloudrepo in $cloudrepos)
  {
    
        #
        # basic info on repo
        #
        ($cloudrepo | Format-List -Property Name, CloudProvider, Description, isAvailable, IsWanAcceleratorEnabled | Out-String).Trim()
        
        #
        # get info from provider
        #
        $resource = ((Get-VBRCloudProvider -name $cloudrepo.CloudProvider).resources | where { $_.RepositoryName -eq $cloudrepo.name})
        write-host "allocated : " $resource.repositoryAllocatedSpace
        
        #
        # @veeam: pls. make this info easier to get
        #
        $used = [Math]::Round([Decimal]([Veeam.Backup.Core.CBackupRepository]::GetRepositoryBackupsSize($cloudrepo.Id.Guid))/1048576,0)
        write-host "used : " $used
  }
}

#
# get backups from cloud repo that are not policy: must be a local job
# (multiple B&R servers might write to a cloud repo: filter them out)
#
$cloudjobs =(Get-VBRbackup | where {$_.RepositoryType -match 'Cloud' -and $_.JobType -notmatch '(Policy)'})

if ($cloudjobs)
{

  #
  # identify service to checkmk
  #
  echo "<<<veeamcc_tenant_cloudjobs>>>"
  foreach ($cloudjob in $cloudjobs)
  {
    
    #
    # only check if an enabled job is found
    #
    $localjob=Get-VBRjob -name $cloudjob.name.split('\\')[0] | where {$_.IsScheduleEnabled -eq $true }
    if ($localjob)
    {
          #
          # basic info on job
          #     
          ($cloudjob | Format-List -Property Name, Id, LastPointCreationTime, VmCount | Out-String -Width 999).Trim()
        
          #
          # list restore points in job
          #
          $cloudjob | Get-VBRRestorePoint | sort-object name | select Name -unique -expandproperty Name
    }
  }
}

#
# job summary
#
if ($cloudjobs)
{

  #
  # identify service to checkmk
  #
  echo "<<<veeamcc_tenant_jobsummary>>>"
  foreach ($cloudjob in $cloudjobs)
  {
    
        #
        # basic info on job
        #       
        write-host "veeamcc_tenant_jobsummary" ($cloudjob | Format-List  Name | Out-String -Width 999).Trim()
        
        #
        # list restore points in job
        #
        $cloudjob | Get-VBRRestorepoint | select Name -unique -expandproperty Name
        
  }
}

#
# This is the end, my friend.
#
exit


